# -*- coding: utf-8 -*-
from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class DjeymConfig(AppConfig):
    name = 'djeym'
    verbose_name = _('Yandex maps')
