.active-tile[data-v-c5beb3aa]{position:absolute;top:1px;right:7px}.pos-screenshot[data-v-c5beb3aa]{position:relative;top:2px;left:2px}.sample-color[data-v-366650f6]{width:100%;height:28px;position:relative;border:1px solid #bdbdbd;background:url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAGElEQVQYlWNgYGCQwoKxgqGgcJA5h3yFAAs8BRWVSwooAAAAAElFTkSuQmCC") repeat}.sample-color__selected-tone[data-v-366650f6]{position:absolute;top:0;right:0;bottom:0;left:0}.valign-title[data-v-2acd5962]{top:-16px!important}.pos-icon[data-v-71d25630]{position:relative;top:2px}.icon-marker[data-v-781b3203]{z-index:2;cursor:pointer}.djeym-ymap[data-v-3351a356]{min-height:300px!important;position:absolute;top:64px;right:0;bottom:0;left:0}.browserupgrade{position:fixed;top:0;right:0;bottom:0;left:0;z-index:11000;background:rgba(0,0,0,.9)}.browserupgrade div{color:#bdbdbd;font-size:18px;line-height:28px;text-align:center;margin:10% 20px auto 20px;padding:20px;border:2px dashed #616161;font-family:Roboto,sans-serif!important}.browserupgrade span{color:#4caf50;font-size:16px;border:2px solid #4caf50;border-radius:50px;padding:2px 8px 3px;margin-right:10px}.browserupgrade a,.browserupgrade span{font-family:Roboto,sans-serif!important}.browserupgrade a{color:#2196f3!important;font-size:18px!important;text-decoration:underline!important}.browserupgrade a:hover{color:#f44336!important}.noscript{position:fixed;top:0;right:0;bottom:0;left:0;z-index:11000;background:rgba(0,0,0,.9)}.noscript div{color:#bdbdbd;font-size:18px;line-height:28px;text-align:center;margin:10% 20px auto 20px;padding:20px;border:2px dashed #616161}.noscript div,.noscript span{font-family:Roboto,sans-serif!important}.noscript span{color:#ffc107;font-size:22px;border:2px solid #ffc107;border-radius:50px;padding:2px 8px 5px;margin-right:10px}.noscript a{color:#2196f3!important;font-size:18px!important;text-decoration:underline!important;font-family:Roboto,sans-serif!important}.noscript a:hover{color:#f44336!important}#djeymModalLock{display:none;position:absolute;top:0;right:0;bottom:0;left:0;z-index:10000;background-color:#fff;opacity:1;-webkit-transition-property:opacity;transition-property:opacity;-webkit-transition-duration:.6s;transition-duration:.6s;-webkit-transition-delay:0s;transition-delay:0s;-webkit-transition-timing-function:linear;transition-timing-function:linear}#djeymLoadIndicator{display:none;position:absolute;top:50%;left:50%}@-webkit-keyframes djeym-spin{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(359deg);transform:rotate(359deg)}}@keyframes djeym-spin{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(359deg);transform:rotate(359deg)}}ymaps[class$=-listbox__list-item-text]{max-width:none!important;font-size:14px!important;line-height:32px!important;font-family:Roboto,sans-serif!important}ymaps[class$=-control-popup-parent]{z-index:2!important}.djeym_ballon_body,.djeym_ballon_footer,.djeym_ballon_header{display:block;width:100%!important;max-width:322px!important;font-family:Roboto,sans-serif!important}.djeym_ballon_header{margin:0 0 5px;font-size:120%;font-weight:500;color:#212121}.djeym_ballon_body{font-size:13px;line-height:1.6;color:#212121}.djeym_ballon_footer{margin:5px 0 0;font-size:90%;color:#424242}.djeym_ballon_header *{margin:0!important}.djeym_ballon_body p,.djeym_ballon_footer p{margin-bottom:5px!important}.djeym_layout_cluster_icon{border-radius:60px}.djeym_layout_cluster_icon span{font-size:12px;font-weight:500;padding:2px 5px;border-radius:20px;font-family:Roboto,sans-serif!important}.djeym-curs-p{cursor:pointer}.djeym-pos-relative{position:relative!important}.djeym-hide{display:none}.djeym-white-space-normal{white-space:normal!important}.djeym-fill-hight{height:100%!important}.djeym-fake-buttons{display:inline-block;padding:0 5px;border-radius:20px;margin-bottom:5px}