#djeymModalLock,.djeym-ymap[data-v-1a3baa09]{position:absolute;top:0;right:0;bottom:0;left:0}#djeymModalLock{display:none;z-index:10000;background-color:#fff;opacity:1;-webkit-transition-property:opacity;transition-property:opacity;-webkit-transition-duration:.6s;transition-duration:.6s;-webkit-transition-delay:0s;transition-delay:0s;-webkit-transition-timing-function:linear;transition-timing-function:linear}#djeymLoadIndicator{display:none;position:absolute;top:50%;left:50%}@-webkit-keyframes djeym-spin{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(359deg);transform:rotate(359deg)}}@keyframes djeym-spin{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(359deg);transform:rotate(359deg)}}.v-application--wrap{min-height:0!important}.v-snack{position:absolute!important}.v-snack--vertical .v-snack__content{padding:16px 16px 8px 5px!important}.v-overlay{position:absolute!important}ymaps[class$=-listbox__list-item-text]{max-width:none!important;font-size:14px!important;line-height:32px!important;font-family:Roboto,sans-serif!important}ymaps[class$=-control-popup-parent]{z-index:2!important}ymaps input{font-family:Arial,Helvetica,sans-serif!important;font-size:13px!important;line-height:28px!important}ymaps input[class$=-route-panel-input__input]{border-left:31px solid transparent!important}ymaps input[class$=-searchbox-input__input]{border-left:9px solid transparent!important}.djeym_ballon_body,.djeym_ballon_footer,.djeym_ballon_header{display:block;width:100%!important;max-width:322px!important;font-family:Roboto,sans-serif!important}.djeym_ballon_header{margin:0 0 5px;font-size:120%;font-weight:500;color:#212121}.djeym_ballon_body{font-size:13px;line-height:1.6;color:#212121}.djeym_ballon_footer{margin:5px 0 0;font-size:90%;color:#424242}.djeym_ballon_header *{margin:0!important}.djeym_ballon_body p,.djeym_ballon_footer p{margin-bottom:5px!important}.djeym_layout_cluster_icon{border-radius:60px}.djeym_layout_cluster_icon span{font-size:12px;font-weight:500;padding:2px 5px;border-radius:20px;font-family:Roboto,sans-serif!important}.djeym-pos-relative{position:relative!important}.djeym-fill-hight{height:100%!important}.djeym-hide{display:none}