# coding: utf-8
#   ____         ____    __    __
#  /\  _`\    __/\  _`\ /\ \  /\ \/'\_/`\
#  \ \ \/\ \ /\_\ \ \L\_\ `\`\\/'/\      \
#   \ \ \ \ \\/\ \ \  _\L`\ `\ /'\ \ \__\ \
#    \ \ \_\ \\ \ \ \ \L\ \`\ \ \ \ \ \_/\ \
#     \ \____/_\ \ \ \____/  \ \_\ \ \_\\ \_\
#      \/___//\ \_\ \/___/    \/_/  \/_/ \/_/
#            \ \____/
#             \/___/

DjEYM_VERSION = (2, 1, 19)
PYTHON_VERSION = (3, 6)
DJANGO_VERSION = (2, 0)
VUE_VERSION = (2, 6, 11)
VUETIFY_VERSION = (2, 2, 1)

__title__ = 'DjEYM (django-editor-ymaps)'
__djeym_version__ = '.'.join(map(str, DjEYM_VERSION))
__python_version__ = '.'.join(map(str, PYTHON_VERSION))
__django_version__ = '.'.join(map(str, DJANGO_VERSION))
__vue_version__ = '.'.join(map(str, VUE_VERSION))
__vuetify_version__ = '.'.join(map(str, VUETIFY_VERSION))
__author__ = 'kebasyaty'
__license__ = 'MIT'
__copyright__ = 'Copyright (c) 2014 kebasyaty'

default_app_config = 'djeym.apps.DjeymConfig'
