.logo_djeym {
  margin: 0 0 10px;
}

.logo_djeym img {
  width: 100px;
}

#id_center_map,
#id_check_icon_offset_map {
  width: 80%;
  height: 400px;
  position: relative;
}

label[for="id_center_map"],
label[for="id_check_icon_offset"] {
  font-weight: bold;
  color: #424242;
  float: none !important;
  width: auto !important;
}

label[for="id_disable_standard_icons"] {
  color: #2196F3;
  font-weight: bold;
  font-size: 14px;
}

.editing_map_link_wrapper {
  position: relative;
  margin: 0 0 20px;
}

.editing_map_link_wrapper a {
  position: relative;
  top: 3px;
}

.editing_map_link_wrapper a:link,
.editing_map_link_wrapper a:visited {
  text-align: center;
  text-decoration: none;
  display: inline-block;
  background-color: transparent;
}

.editing_map_link_wrapper a:hover,
.editing_map_link_wrapper a:active {
  background-color: transparent;
}

.editing_map_link_wrapper--table {
  border-collapse: collapse !important;
}

.editing_map_link_wrapper--table td {
  height: 30px;
  max-height: 30px;
  border-color: transparent !important;
  vertical-align: middle !important;
}

.editing_map_link_wrapper--table td:nth-child(1) {
  background-color: #ffd54f;
  padding: 0 0 0 8px !important;
  color: #212121;
}

.editing_map_link_wrapper--table td:nth-child(2) {
  background-color: #ffd54f;
  color: #212121;
  font-size: 16px;
  padding: 0 10px 0 5px !important;
}

.editing_map_link_wrapper--table td:nth-child(3) {
  padding: 0;
}

.hint_center_map,
.hint_check_icon_offset {
  color: #2196F3;
  font-size: 16px;
  font-weight: bold;
  margin: 0 0 10px;
  font-style: italic;
}

.field-check_icon_offset,
.hint_check_icon_offset {
  display: none;
}

.djeym_hint_custom_icons {
  margin: 10px 0 20px;
  color: #2196F3;
  font-size: 16px;
  font-weight: bold;
  font-style: italic;
}

.hint_offset {
  height: 32px;
  position: relative;
  top: -1px;
  left: 5px;
}

.view_icon {
  font-size: 28px;
  position: relative;
  top: 7px;
  left: 10px;
  color: #616161;
}

.icon_list_wrap {
  display: none;
  width: 300px;
  height: 410px;
  position: relative;
  top: 0;
  left: 10px;
  border: 1px solid #ccc;
  border-radius: 4px;
}

.icon_list_wrap__top_block {
  width: 100%;
  text-align: right;
  border-bottom: 1px solid #ccc;
}

.icon_list_wrap__center_block {
  width: 100%;
  height: 360px;
  overflow-x: hidden;
  overflow-y: scroll;
  border-bottom: 1px solid #ccc;
}

.icon_list_wrap__icon {
  display: inline-block;
  width: 60px;
  height: 60px;
  background-position: center;
  background-repeat: no-repeat;
  background-size: contain;
  margin: 5px;
  cursor: pointer;
}

.icon_list_wrap__close {
  font-size: 28px;
  color: #BDBDBD;
  padding-right: 2px;
  cursor: pointer;
}

.change_slug_icon {
  color: #4CAF50;
  cursor: pointer;
}

.block_ip {
  color: #F44336;
  cursor: pointer;
}

.category_icon {
  color: #616161;
  font-size: 20px;
}

label[for="id_is_cluster"] {
  color: #2196F3;
  font-weight: bold;
  font-size: 14px;
}

#id_custom_cluster_icon,
#id_collection_example_icon,
#id_tile_screenshot,
#id_icon_load_indicator {
  display: none;
  max-height: 60px;
  position: relative;
  top: 0;
  left: 20px;
}

.custom_cluster_icon_wrapper,
.icon_collection_wrapper,
.tile_screenshot_wrapper,
.load_indicator_icon_wrapper {
  overflow: visible !important;
}

.djeym_category_color {
  width: 26px;
  height: 26px;
}

/* Marker offset - Buttons for touch screen. */

.marker_offset_btn {
  display: inline-block;
  margin-left: 10px;
  cursor: pointer;
}

/* Import/Export - Icon Collection.
   Import/Export - Source tile layer */

.import_icon_collection_link,
.import_tile_source_link {
  background-color: #ffd54f !important;
  color: #212121 !important;
  background-image: url(../img/plus.svg) !important;
}

.export_tile_source_link {
  background-color: #ffd54f !important;
  color: #212121 !important;
  background-image: url(../img/import.svg) !important;
}

.export_icon_collection_link {
  position: relative;
  background-color: #ffd54f;
  color: #212121 !important;
  border-radius: 20px;
  padding: 5px 14px 5px;
  text-transform: uppercase;
  font-weight: 400;
  letter-spacing: 0.5px;
  font-size: 11px;
}

.export_icon_collection_link div {
  display: inline-block;
  width: 16px;
  height: 16px;
  position: relative;
  top: 4px;
  left: 3px;
  background: url(../img/import.svg) no-repeat center;
  background-size: cover;
}

.tile_go_to_website_btn {
  display: inline-block;
  margin-left: 10px;
}

/* Modal lock */

#djeymModalLock {
  display: none;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 10000;
  background-color: #FFFFFF;
  opacity: .85;
  transition-property: opacity;
  transition-duration: 1s;
  transition-delay: 0s;
  transition-timing-function: linear;
}

.djeym-load-indicator {
  width: 64px;
  height: 64px;
  position: absolute;
  top: 50%;
  left: 50%;
  margin: -32px 0 0 -32px;
  content: url('../../djeym/img/spinner.svg');
  animation: djeym-spin 1s infinite linear;
}

@keyframes djeym-spin {
  0% {
    transform: rotate(0deg);
  }

  100% {
    transform: rotate(359deg);
  }
}

/* Helpers */

.hidden {
  display: none !important;
}